<?php
// Quick-LP
// Copyright (c) Radius17
// Web: https://quick-lp.ru
// Commercial license https://quick-lp.ru/license.txt
// THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// Revision: 256b5dd (2020-07-20 19:35:04)
//

defined('_QUICK_LP') or die("Access denied");

spl_autoload_register(function($className) {
//function __autoload($className) {
	$scriptPath=QLP_CORE.DS.$className.'.php';
	if (is_file($scriptPath)) require_once $scriptPath;
	if (interface_exists($className) || class_exists($className)) return true;
	die("Absent CLASS or INTERFACE: ".$className);
//}
});
class QLPManager extends QLPSimpleObject{
	private static $_instance = null;
			
	private static function createInstance() {
		if (self::$_instance == null) {
			self::$_instance = new self();
		}
	}
	public static function getInstance() {
		self::createInstance();
		return self::$_instance;
	}
	private function __construct() {
		if(function_exists("mb_internal_encoding")) mb_internal_encoding("UTF-8");
		require_once QLP_CONFIG."config.php";
		if(QLPConfig::$debugMode) {
			ini_set('display_errors',1);
			error_reporting(E_ALL);
			define('QLP_MINIFIED_ASSETS', 0);
			define('QLP_DEBUG_ASSETS', 1);
		} else {
			define('QLP_MINIFIED_ASSETS', 1);
			define('QLP_DEBUG_ASSETS', 0);
		}
		ini_set('memory_limit',QLPConfig::$adminMemoryLimit."M");
		ini_set('max_execution_time',QLPConfig::$adminTimeLimit);
		
		$this->initSimpleObject();
		QLPDebugger::getInstance()->milestone("Start");
		QLPUtil::checkServerSettings(true);
		QLPUtil::checkIntrusion();
		QLPSession::createInstance();
		/* раньше тут подключались скрипты */
		QLPText::parseLanguage(QLPConfig::$defaultLang);
		QLPPlugin::initialize();
		QLPEvent::raise("admin.start");
//		QLPWidget::initialize();
	}
	public function proceed(){
		$option=QLPRequest::getSafe("option");
		$module=QLPRequest::getSafe("module","panel");
		$task=QLPRequest::getSafe("task","render");
		if($option!="ajax") {
			QLPTemplate::getInstance()->addScript("/redistribution/js/jquery/jquery-1.9.1.min.js");
//			QLPTemplate::getInstance()->addScript("/redistribution/js/jquery/jquery-migrate-1.1.1.min.js");
			QLPTemplate::getInstance()->addScript("/redistribution/js/jquery/jquery-ui-1.10.3.min.js");
			QLPTemplate::getInstance()->addScript("/redistribution/fancybox/jquery.fancybox.min.js");
			QLPTemplate::getInstance()->addStyleSheet("/redistribution/fancybox/jquery.fancybox".(QLP_MINIFIED_ASSETS ? ".min" : "").".css", true);
			QLPTemplate::getInstance()->addScript("/redistribution/js/jquery.plugins/jquery_cookie.min.js");
			QLPTemplate::getInstance()->addScript("/redistribution/js/jquery.plugins/jquery.sticky.js");
		}
		ob_start();
		if(!QLPSession::getInstance()->isLoggedIn()) {
			if($option=="ajax") {
				echo "Access denied";
				QLPUtil::halt();
			} else {
				$module="login";
				if($task!="authorize") $task="showForm";
			}
		}
		if (is_file(QLP_MANAGE.$module.DS."index.php")) {
			require_once QLP_MANAGE.$module.DS."index.php";
			$class_name=$module."QLPModule";
			if(class_exists($class_name)) {
				if(!$class_name::getInstance()->proceed($task)) echo QLPText::_("Proceed failed");
			} else echo QLPText::_("Task class absent");
		} else echo QLPText::_("Task file absent");
		$content = ob_get_contents();
		ob_end_clean();
		if($option=="ajax") {
			echo $content;
			QLPUtil::halt();
		} else {
			QLPTemplate::getInstance()->render($content);
		}
	}
	public function getConfigVal($name, $default=""){
		if(property_exists('QLPConfig',$name)) 	return QLPConfig::$$name;
		else return null;
	}
}
?>