<?php 
// Quick-LP
// Copyright (c) Radius17
// Web: https://quick-lp.ru
// Commercial license https://quick-lp.ru/license.txt
// THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// Revision: 2b05650 (2016-01-22 14:05:05)
//

defined('_QUICK_LP') or die("Access denied");

class QLPFilesystem{
	private static $_hiddenfiles=array(	'.svn', 'index.php', 'index.html',	'.htaccess','.htpasswd','web.config', '.', '..');
	
	public static function getFolders($folder="", $hiddenfiles="", $full=false){
		if (!$hiddenfiles) $hiddenfiles = self::$_hiddenfiles;
		else $hiddenfiles=array_merge($hiddenfiles,self::$_hiddenfiles);
		clearstatcache();
		if(!is_dir($folder)) return false;
		$allfiles = scandir($folder);
		$folders=array();
		foreach($allfiles as $file) {
			if (in_array($file, $hiddenfiles))  continue;
			if(is_dir($folder.DS.$file)) {
				$folders[$file]["folder"] = 1;
				$folders[$file]["filename"] = $file;
				if ($full){
					$folders[$file]["filesize"] = round(filesize($folder.DS.$file)/1024,3);
					$folders[$file]["filedate"] = date ("d.m.Y H:i", filemtime($folder.DS.$file));
				}
			}
		}
		if (count($folders)) ksort($folders, SORT_REGULAR);
		return $folders;
	}
	public static function getFiles($folder="", $filetypes=array(), $hiddenfiles="", $fullinfo=false){
		if (!$hiddenfiles) $hiddenfiles = self::$_hiddenfiles;
		clearstatcache();
		if(!is_dir($folder)) return false;
		$allfiles = scandir($folder);
		foreach($allfiles as $file) {
			if (in_array($file, $hiddenfiles))  continue;
			if(count($filetypes) && !in_array(self::getExtension($file), $filetypes))  continue;
			if(is_file($folder.DS.$file)) {
				$files[$file]["folder"] = 0;
				$files[$file]["filename"] = $file;
				if ($fullinfo){
					$files[$file]["filesize"] = round(filesize($folder.DS.$file)/1024,3);
					$files[$file]["filedate"] = date ("d.m.Y H:i", filemtime($folder.DS.$file));
				}
			}
		}
		if (!isset($files)) return array();
		if (count($files)) ksort($files, SORT_REGULAR);
		return $files;
	}
	public static function copyFolder($src,$dest,$force=false){
		$src = rtrim($src, DS);
		$dest = rtrim($dest, DS);
		if (!is_dir($src)) return false;
		if (is_dir($dest) && !$force) return false;
		if (!self::checkFolder($dest,$force)) return false;
		$files=scandir($src);
		if($files && count($files)){
			foreach ($files as $file)	{
				$sfid = $src.DS.$file;
				$dfid = $dest.DS.$file;
				switch (filetype($sfid)) {
					case 'dir':
						if ($file != '.' && $file != '..')	{
							$ret = self::copyFolder($sfid, $dfid, $force);
							if (!$ret) return false;
						}
						break;
					case 'file':
						if (!@copy($sfid, $dfid)) return false;
						break;
				}
			}
		}
		return true;
	}
	public static function checkFolder($path, $force){
		if(is_dir($path)) return true;
		else {
			if ($force) {
				if(!mkdir($path, 0755, true)) return false;
				else {
					self::checkIndexFile($path,true);
					return true;
				}
			}	else return false;
		}
	}
	public static function checkIndexFile($path,$create=false,$content=""){
		$file=$path.DS."index.html";
		if (!is_file($file)) {
			if (!$handle = fopen($file, 'wb')) return false;
			fwrite($handle, $content);
			fclose($handle);
			return true;
		} else return true;
	}
	public static function removeFolder($src,$force=0) {
		$src = rtrim($src, DS);
		$result = true;
		$files=scandir($src);
		foreach ($files as $file)	{
			$sfid = $src.DS.$file;
			switch (filetype($sfid)) {
				case 'dir':
					if ($file != '.' && $file != '..')	{
						if ($force)	$result = self::removeFolder($sfid, $force);
						else $result = false;
					}
					break;
				case 'file':
					if ($force) $result = unlink($sfid);
					else $result = false;
					break;
			}
		}
		if ($result) $result=rmdir($src);
		return $result;
	}
	public static function stripExtension($filename) {
		return pathinfo($filename, PATHINFO_FILENAME);
	}
	public static function getExtension($filename) {
		return pathinfo($filename, PATHINFO_EXTENSION);
	}
}
?>