<?php
// Quick-LP
// Copyright (c) Radius17
// Web: https://quick-lp.ru
// Commercial license https://quick-lp.ru/license.txt
// THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// Revision: a974ae2 (2016-05-10 08:47:48)
//

defined('_QUICK_LP') or die("Access denied");

final class QLPMailer {
	private static $data_charset  = "utf-8";
	private static $send_charset  = "utf-8";
	private static $_end  = "\r\n";
	
	public static function send($mail_to, $subject, $message, $smtp_charset="UTF-8", $headers="") {
		$send = "Date: ".date("D, d M Y H:i:s") . " UT\r\n";
		$send .= "Subject: ".self::mime_header_encode($subject).self::$_end;
		if ($headers) $send .= $headers."\r\n\r\n";
		else {
			$send .= "Reply-To: ".QLPConfig::$mailerFrom."\r\n";
			$send .= "MIME-Version: 1.0\r\n";
			$send .= "Content-Type: text/plain; charset=\"".$smtp_charset."\"\r\n";
			$send .= "Content-Transfer-Encoding: 8bit\r\n";
			$send .= "From: \"".QLPConfig::$mailerFromname."\" <".QLPConfig::$mailerFrom.">\r\n";
			$send .= "To: $mail_to <$mail_to>\r\n";
			$send .= "X-Priority: 3\r\n\r\n";
		}
		$send .=  $message."\r\n";
		if( !$socket = fsockopen(QLPConfig::$mailerSMTPHost, QLPConfig::$mailerSMTPPort, $errno, $errstr, 30) ) {
			QLPDebugger::getInstance()->warning($errno."&lt;br&gt;".$errstr);
			return false;
		}
	
		if (!self::parseServerResponse($socket, "220", __LINE__)) return false;
	
		fputs($socket, "HELO " . QLPConfig::$mailerSMTPHost . "\r\n");
		if (!self::parseServerResponse($socket, "250", __LINE__)) {
			QLPDebugger::getInstance()->warning("Cant send HELO!");
			fclose($socket);
			return false;
		}
		fputs($socket, "AUTH LOGIN\r\n");
		if (!self::parseServerResponse($socket, "334", __LINE__)) {
			QLPDebugger::getInstance()->warning("Unable to find answer");
			fclose($socket);
			return false;
		}
		fputs($socket, base64_encode(QLPConfig::$mailerSMTPUser) . "\r\n");
		if (!self::parseServerResponse($socket, "334", __LINE__)) {
			QLPDebugger::getInstance()->warning("Login incorrect");
			fclose($socket);
			return false;
		}
	
		fputs($socket, base64_encode(QLPConfig::$mailerSMTPPassword) . "\r\n");
		if (!self::parseServerResponse($socket, "235", __LINE__)) {
			QLPDebugger::getInstance()->warning("Password incorrect");
			fclose($socket);
			return false;
		}
	
		fputs($socket, "MAIL FROM: <".QLPConfig::$mailerSMTPUser.">\r\n");
		if (!self::parseServerResponse($socket, "250", __LINE__)) {
			QLPDebugger::getInstance()->warning("Cannot send command MAIL FROM:");
			fclose($socket);
			return false;
		}
	
		fputs($socket, "RCPT TO: <" . $mail_to . ">\r\n");
		if (!self::parseServerResponse($socket, "250", __LINE__)) {
			QLPDebugger::getInstance()->warning("Cannot send command RCPT TO:");
			fclose($socket);
			return false;
		}
	
		fputs($socket, "DATA\r\n");
		if (!self::parseServerResponse($socket, "354", __LINE__)) {
			QLPDebugger::getInstance()->warning("Cannot send command DATA");
			fclose($socket);
			return false;
		}
	
		fputs($socket, $send."\r\n.\r\n");
		if (!self::parseServerResponse($socket, "250", __LINE__)) {
			QLPDebugger::getInstance()->warning("Unable to send message body!");
			fclose($socket);
			return false;
		}
		fputs($socket, "QUIT\r\n");
		fclose($socket);
		return true;
	}
	private static function parseServerResponse($socket, $response, $line = __LINE__) {
		$server_response="";
		while (substr($server_response, 3, 1) != ' ') {
			if (!($server_response = fgets($socket, 256))) {
				QLPDebugger::getInstance()->error("Mail send problems! Response:".$response.", Line:".$line);
				return false;
			}
		}
		if (!(substr($server_response, 0, 3) == $response)) {
			QLPDebugger::getInstance()->error("Mail send problems! Response:".$response.", Line:".$line);
			return false;
		}
		return true;
	}
	public static function mime_header_encode($str) {
		if(self::$data_charset != self::$send_charset) {
			$str = iconv(self::$data_charset, self::$send_charset, $str);
		}
		return "=?" . self::$send_charset . "?B?" . base64_encode($str) . "?=";
	}
}
?>