<?php
// Quick-LP
// Copyright (c) Radius17
// Web: https://quick-lp.ru
// Commercial license https://quick-lp.ru/license.txt
// THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// Revision: 85191b9 (2022-07-12 18:46:47)
//

defined('_QUICK_LP') or die("Access denied");

class filemanagerQLPModule extends QLPSimpleObject{
	private static $_instance = null;
	private $fm_path="";
	private $fm_url="";
	private $filemanager_homepage="https://github.com/Radius17/PHP-KCFinder/";
	private $filemanager_url="https://codeload.github.com/Radius17/PHP-KCFinder/zip/master";
			
	private static function createInstance() {
		if (self::$_instance == null) {
			self::$_instance = new self();
		}
	}
	public static function getInstance() {
		self::createInstance();
		return self::$_instance;
	}
	private function __construct() {
		$this->initSimpleObject();
		$this->fm_path=QLP_SITE.'redistribution'.DS.'php'.DS.'kcfinder-master'.DS;
		$this->fm_url='/redistribution/php/kcfinder-master/';
	}
	public function proceed($task=""){
		switch ($task){
			case "install":
				if(!is_dir($this->fm_path)){
					$this->installFilemanager();
				} else {
					$this->renderFilemanager();
				}
			break;
			default:
				echo '<div class="panel-wrapper module-filemanager"><div class="row"><div class="col-md-12">';
				echo '<h1 class="panel-title">'.QLPText::_("Filemanager").'</h1>';
				echo '<div id="filemanager">';
				if(is_dir($this->fm_path)){
					$this->renderFilemanager();
				} else {
					echo QLPText::_("We recommend to use").'&nbsp;<a class="underline" target="_blank" href="'.$this->filemanager_homepage.'">KCFinder (version from Radius17)</a><br />';
					echo QLPText::_("It is distributed under licenses").":<br />";
					echo '<a class="underline" href="http://opensource.org/licenses/GPL-3.0" target="_blank">GNU General Public License, version 3</a><br />';
					echo '<a class="underline" href="http://opensource.org/licenses/LGPL-3.0" target="_blank">GNU Lesser General Public License, version 3</a><br />';
					echo QLPText::_("If you are agree on terms of above licenses click").'&nbsp;<a class="underline" href="/manager.php?module=filemanager&amp;task=install">'.QLPText::_("here").'</a>&nbsp;'.QLPText::_("to download and install it");
				}
				echo '</div></div></div>';
				echo '</div>';
			break;
		}
		return true;
	}
	private function renderFilemanager(){
		echo '<iframe src="'.$this->fm_url.'" width="100%" height="600">Unsupported!</iframe>';		
	}
	private function installFilemanager(){ 
		// возможно нужно держать путь скачивания в конфиге
		// и добавить в билдер исключения для сборки
		if(is_dir(QLP_TMP."kcfinder-master")) QLPFilesystem::removeFolder(QLP_TMP."kcfinder-master");
		$filename=QLP_TMP."kcfinder-master.zip";
		$package = fopen($filename, 'wb');
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $this->filemanager_url);
		curl_setopt($ch, CURLOPT_FAILONERROR, 1);
		curl_setopt($ch, CURLOPT_FRESH_CONNECT,1);
		curl_setopt($ch, CURLOPT_FILE, $package);
		curl_setopt($ch, CURLOPT_HEADER, 0); // allow redirects
		curl_setopt($ch, CURLOPT_TIMEOUT, 30);
		curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 30);
		curl_setopt ($ch, CURLOPT_SSL_VERIFYPEER, 0);
		curl_setopt ($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_USERAGENT, $_SERVER['HTTP_USER_AGENT']);
		if(curl_exec($ch)) {
			// распаковываем
			curl_close($ch); fclose($package);
			if($this->unzipFilemanager($filename)){
				if($this->replaceConfigVals()){
					if(QLPFilesystem::copyFolder(QLP_TMP."kcfinder-master", QLP_SITE."redistribution".DS."php".DS."kcfinder-master", true) && QLPFilesystem::removeFolder(QLP_TMP."kcfinder-master",1)){
						QLPUtil::redirect("/manager.php?module=filemanager");
					} else {
						QLPUtil::redirect("/manager.php",QLPText::_("Error at copying files"));
					}
				} else {
					QLPUtil::redirect("/manager.php",QLPText::_("Error at configuring filemanager"));
				}
			} else {
				QLPUtil::redirect("/manager.php",QLPText::_("Error at unzipping package"));
			}
		} else {
			curl_close($ch); fclose($package);
			QLPUtil::redirect("/manager.php",QLPText::_("Error at file loading with code")." : ".curl_error($ch)); 
		}
	}
	private function replaceConfigVals(){
		$config=QLP_TMP.'kcfinder-master'.DS.'conf'.DS.'config.php';
		$replace = "'REPLACE_WITH_YOUR_CMS'";
		$with = "'QLP'";
		$data = file_get_contents($config);
		$data=str_replace($replace, $with, $data);
		return file_put_contents($config,$data);
	}
	private function unzipFilemanager($filename){
		$zip = new ZipArchive;
		if (!$zip) return false;
		$res = $zip->open($filename);
		if ($res === TRUE) {
			$zip->extractTo(QLP_TMP);
			$zip->close();
			unlink($filename);
		} else {
			echo "failed";
			return false;
		}
		return true;
	}
}