<?php
// Quick-LP
// Copyright (c) Radius17
// Web: https://quick-lp.ru
// Commercial license https://quick-lp.ru/license.txt
// THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// Revision: 6fa5d6f (2020-09-06 13:28:27)
//

defined('_QUICK_LP') or die("Access denied");

class pagesQLPModule extends QLPSimpleObject{
	private static $_instance = null;
	private $file_types=array('txt', 'html');
	
	private static function createInstance() {
		if (self::$_instance == null) {
			self::$_instance = new self();
		}
	}
	public static function getInstance() {
		self::createInstance();
		return self::$_instance;
	}
	private function __construct() {
		$this->initSimpleObject();
	}
	public function proceed($task=""){
		switch ($task){
			case "modify":
				$file=QLPRequest::getSafe("file","");
				$edit_mode=QLPRequest::getSafe("edit_mode","");
				$file_text="";
				if($file){
					$filename=base64_decode($file);
					if(is_file(QLP_DATA."pages".DS.$filename)){
						$file_text=file_get_contents(QLP_DATA."pages".DS.$filename);
					} else $filename="";
				} else $filename="";
				$this->renderEditorForm($filename, $file_text, "", $edit_mode);
			break;	
			case "save":
				$file=QLPRequest::getSafe("filename","");
				$edit_mode=QLPRequest::getSafe("edit_mode","");
				$old_filename=QLPRequest::getSafe("old_filename","");
				if($old_filename) $old_filename=QLP_DATA."pages".DS.base64_decode($old_filename);
				$file_text=QLPRequest::get("filecontents","");
				if($file){
					$ext = QLPFilesystem::getExtension($file);
					if(in_array($ext, $this->file_types)){
						$file = QLPFilesystem::stripExtension($file);
					} else {
						$ext = 'txt';
					}
					$file = QLPText::translit($file).".".$ext;
					$filename=QLP_DATA."pages".DS.$file;
					if($file == 'index.html' || (is_file($filename) && $filename!=$old_filename)){
						$message=QLPText::_("File exists");
						$this->renderEditorForm($file, $file_text, $message, $edit_mode);
					} else {
						if(file_put_contents($filename, $file_text)===false){
							$message=QLPText::_("Failed to saved");
							$this->renderEditorForm($file, $file_text, $message, $edit_mode);
						} else {
							if(is_file($old_filename) && $filename!=$old_filename) @unlink($old_filename);
							if(QLPRequest::getSafe("return")=="front") QLPUtil::redirect("/", QLPText::_("Saved"));
							else QLPUtil::redirect("/manager.php?module=pages", QLPText::_("Saved"));
						}
					}
				} else {
					$message=QLPText::_("Filename absent");
					$this->renderEditorForm($file, $file_text, $message, $edit_mode);
				}
			break;	
			case "delete":
				$file=QLPRequest::getSafe("file","");
				if($file){
					$filename=QLP_DATA."pages".DS.base64_decode($file);
					if(is_file($filename)){
						if(unlink($filename)) $message=QLPText::_("File deleted")." :".$filename;
						else $message=QLPText::_("Unable to delete file")." :".$filename;
					} else $message=QLPText::_("Unable to delete file")." :".$filename;
				} else $message=QLPText::_("Unable to delete file");
				QLPUtil::redirect("/manager.php?module=pages", $message);
			break;	
			default:
				echo '<div class="panel-wrapper module-pages"><div class="row"><div class="col-md-12">';
				echo '<h1 class="panel-title table-title">'.QLPText::_("Pages").'</h1>';
				echo '<div class="table-wrapper">';
				$enabled = parse_ini_file(QLP_PLUGINS."plugins.ini",false);
				$files=QLPFilesystem::getFiles(QLP_DATA."pages".DS, $this->file_types);
				echo '<div class="row row-title">
						<div class="col-xs-10  col-sm-11 lbl">'.QLPText::_("Filename").'</div>
						<div class="col-xs-2  col-sm-1 data"><a title="'.QLPText::_("Add").'" class="toolbutton" href="/manager.php?module=pages&amp;task=modify"><span class="glyphicon glyphicon-plus"></span></a></div>
					</div>';
				foreach($files as $key=>$file){
					$brief = file_get_contents(QLP_DATA."pages".DS.$key);
					$brief = html_entity_decode($brief);
					$brief = strip_tags($brief);
					$brief = trim($brief, " \t\n\r\0\x0B\xC2\x0D\x0A\xA0");
					$brief = mb_substr($brief, 0, 300, DEF_CP);
//					QLPUtil::pre($brief);
					$brief = str_replace("\"", "&quot;", $brief);
					echo '<div class="row illuminated">
							<div class="col-xs-2 col-sm-1 toolbuttons"><a title="'.QLPText::_("Delete").'" class="toolbutton" onclick="if(confirm(\''.QLPText::_("Really delete").'?\')) return true; else return false; " href="/manager.php?module=pages&amp;task=delete&amp;file='.base64_encode($key).'"><span class="glyphicon glyphicon-remove"></span></a></div>
							<div class="col-xs-8 col-sm-10 infolabel" title="'.$brief.'">'.$key.'</div>
							<div class="col-xs-2 col-sm-1 toolbuttons"><a title="'.QLPText::_("Modify").'" class="toolbutton" href="/manager.php?module=pages&amp;task=modify&amp;file='.base64_encode($key).(QLPFilesystem::getExtension($key)=='txt' ? '&amp;edit_mode=source' : '').'"><span class="glyphicon glyphicon-pencil"></span></a></div>
						</div>';
				}
				echo '</div>';
				echo '</div></div></div>';
			break;
		}
		return true;
	}
	private function renderEditorForm($filename, $file_text, $message, $edit_mode){
		$label_class = 'col-sm-12 lbl';
		$data_class = 'col-sm-12 data';
		echo '<div class="panel-wrapper module-pages"><div class="row"><div class="col-md-12">';
		echo '<form method="post" action="/manager.php">';
		echo '<input type="hidden" value="edit_mode" name="'.$edit_mode.'">';
		echo '<input type="hidden" value="pages" name="module">';
		echo '<input type="hidden" value="save" name="task">';
		echo '<input type="hidden" value="'.QLPRequest::getSafe("return").'" name="return">';
		echo '<input type="hidden" value="'.($filename ? base64_encode($filename) : "").'" name="old_filename">';
		echo '<div class="row row-form"><div class="'.$label_class.'">'.QLPText::_("Filename"),' ('.QLPText::_("in Latin").')</div></div>';
		echo '<div class="row row-form"><div class="'.$data_class.'"><input class="form-control" name="filename" value="'.$filename.'" type="text" required></div></div>';
		echo '<div class="row row-form"><div class="'.$label_class.'">'.QLPText::_("File contents").'</div></div>';
		echo '<div class="row row-form"><div class="'.$data_class.'"><textarea class="form-control" id="filecontents" name="filecontents">'.htmlspecialchars($file_text).'</textarea></div></div>';
		echo '<div class="buttons"><input class=\"button\" type="submit" value="'.QLPText::_("Save").'" /><a class="button" href="'.(QLPRequest::getSafe("return")=="front" ? "/": "/manager.php?module=pages").'">'.QLPText::_("Close").'</a></div>';
		echo '</form>';
		echo '</div></div></div>';
		QLPEvent::raise("editor.render", array("area"=>"filecontents", "edit_mode"=>$edit_mode));
		if($message) QLPTemplate::getInstance()->addScriptDeclaration("$(document).ready(function(){ alert('".$message."'); });");
	}
}